@@ -28,6 +28,9 @@ class TimeoutError(StorageModelError):
     """Timeout error"""
     pass
 
+class MultipathDaemonTimeoutError(TimeoutError):
+    pass
+
 class NotMounted(StorageModelError):
     def __init__(self, mount_point):
         super(NotMounted, self).__init__("path {!r} is not being used by any mount".format(mount_point))
@@ -49,6 +52,9 @@ CHECK_CONDITIONS_TO_CHECK = [
     ('UNIT_ATTENTION', 'POWER ON OCCURRED'),
     ('UNIT_ATTENTION', 'REPORTED LUNS DATA HAS CHANGED'),
     ('UNIT_ATTENTION', 'INQUIRY DATA HAS CHANGED'),
+    ('UNIT_ATTENTION', 'BUS DEVICE RESET FUNCTION OCCURRED'),
+    ('UNIT_ATTENTION', 'ASYMMETRIC ACCESS STATE CHANGED'),
+    ('UNIT_ATTENTION', 'CAPACITY DATA HAS CHANGED'),
     ('ILLEGAL_REQUEST', 'LOGICAL UNIT NOT SUPPORTED'),
 ]
 
@@ -60,6 +66,7 @@ def safe_repr(obj):
 
 def check_for_scsi_errors(func):
     from infi.asi.errors import AsiOSError, AsiSCSIError, AsiCheckConditionError
+    from sys import exc_info
     @wraps(func)
     def callable(*args, **kwargs):
         try:
@@ -77,7 +84,7 @@ def check_for_scsi_errors(func):
             raise
         except (IOError, OSError, AsiOSError, AsiSCSIError), error:
             msg = "device {!r} disappeared during {!r}".format(safe_repr(device), func)
-            logger.debug(msg)
+            logger.error(msg, exc_info=exc_info())
             raise chain(DeviceDisappeared(msg))
     return callable
 
